'use strict';

var fs = require('fs');
var path = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var path__default = /*#__PURE__*/_interopDefaultLegacy(path);

class FileConf {
    constructor(args) {
        if (!args.dirName) {
            throw new Error("'dirName' is required in 'File' configuration type");
        }
        this.dirName = args.dirName;
        if (!fs__default["default"].lstatSync(this.dirName).isDirectory()) {
            throw new Error(`Directory ${this.dirName} doesn't exist`);
        }
    }
    available() {
        return new Promise((resolve, reject) => {
            fs__default["default"].readdir(this.dirName, (err, files) => {
                if (err) {
                    reject(err);
                }
                else {
                    const res = [];
                    files.map(file => {
                        if (/lmConf-(\d+)\.js/.test(file))
                            res.push(parseInt(RegExp.$1));
                    });
                    res.sort();
                    resolve(res);
                }
            });
        });
    }
    lastCfg() {
        return new Promise((resolve, reject) => {
            this.available()
                .then((av) => {
                if (av.length > 0) {
                    // @ts-ignore: av contains only numbers, not undefined
                    resolve(av.pop());
                }
                else {
                    reject('No configuration available');
                }
            })
                .catch(err => {
                reject(err);
            });
        });
    }
    load(cfgNum, fields = []) {
        return new Promise((resolve, reject) => {
            const filename = path__default["default"].join(this.dirName, `lmConf-${cfgNum.toString()}.json`);
            fs__default["default"].access(filename, fs__default["default"].constants.R_OK, err => {
                if (err) {
                    reject(`Unable to read ${filename}: ${err}`);
                }
                else {
                    fs__default["default"].readFile(filename, (err, data) => {
                        if (err) {
                            reject(`Unable to read ${filename}: ${err}`);
                        }
                        else {
                            try {
                                return resolve(JSON.parse(data.toString()));
                            }
                            catch (err) {
                                reject(`JSON parsing error: ${err}`);
                            }
                        }
                    });
                }
            });
        });
    }
    store(fields) {
        return new Promise((resolve, reject) => {
            const mask = process.umask(0o027);
            const data = JSON.stringify(fields);
            fs__default["default"].writeFile(path__default["default"].join(this.dirName, `lmConf-${fields.cfgNum.toString()}.json`), data, err => {
                process.umask(mask);
                if (err) {
                    reject(`Unable to write lmConf-${fields.cfgNum.toString()}.json`);
                }
                else {
                    resolve(true);
                }
            });
        });
    }
}

module.exports = FileConf;
//# sourceMappingURL=index.js.map
